@@ -1,4 +1,4 @@
-/* $Id: ApplicationS.h,v 1.1.1.1 1997/03/19 13:32:19 glgay Exp $ */
+/* $Id: ApplicationS.h,v 1.2 1999/01/14 03:08:53 glgay Exp $ */
 /*
  Copyright (C) 1993, 1994 Jettero Heller
  Copyright (C) 1994, 1995 Peter Williams
@@ -33,10 +33,10 @@ class ApplicationShellClass : public TopLevelShellClass {
    virtual WidgetClass classPointer() { return applicationShellWidgetClass; }
    virtual _XtString className() { return (_XtString) "ApplicationShell"; }
  public:
-   int argc();
+   int argc() const;
    void argc(int);
-   _XtString *argv();
-   void argv(_XtString *);
+   _XtString *argv() const;
+   void argv(const _XtString *);
 };
 
 #endif
