@@ -1,4 +1,4 @@
-/* $Id: MenuB.h,v 1.3 1997/04/07 15:57:13 glgay Exp $ */
+/* $Id: MenuB.h,v 1.5 1998/11/22 15:42:50 glgay Exp $ */
 /*
  Copyright (C) 1993, 1994 Jettero Heller
  Copyright (C) 1994, 1995 Peter Williams
@@ -27,10 +27,12 @@
 #include <Xarm/CascadeB.h>
 
 class MenuButton : public PulldownMenu {
+
  public:
-   CascadeButton button;
+   CascadeButton *button;
    MenuButton(Widget w_parent, char *str, KeySym mn = 0, _XtString name = NULL);
    MenuButton(_XtString name, Widget w_parent);
+   virtual ~MenuButton() { delete button; }
 };
 
 #endif
